==> vue-button-group-2.8.0.tgz: package/lib/index.js <==
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
import { defineComponent, $prefix, $setup, $props } from "@dft-vue-2-opentiny/vue-common";
import PcTemplate from "./pc.js";
import "@dft-vue-2-opentiny/vue-theme/button-group/index.css";
var template = function template2(mode) {
  return PcTemplate;
};
var buttonGroupProps = _extends({}, $props, {
  size: String,
  data: {
    type: Array,
    default: function _default() {
      return [];
    }
  },
  plain: Boolean,
  modelValue: [String, Number],
  disabled: Boolean,
  valueField: {
    type: String,
    default: "value"
  },
  textField: {
    type: String,
    default: "text"
  },
  showMore: Number,
  showEdit: {
    type: Boolean,
    default: false
  },
  border: {
    type: Boolean,
    default: true
  }
});
var ButtonGroup = defineComponent({
  name: $prefix + "ButtonGroup",
  provide: function provide() {
    return {
      buttonGroup: this
    };
  },
  props: buttonGroupProps,
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "2.8.0";
ButtonGroup.model = {
  prop: "modelValue",
  event: "update:modelValue"
};
ButtonGroup.install = function(Vue) {
  Vue.component(ButtonGroup.name, ButtonGroup);
};
ButtonGroup.version = version;
export {
  ButtonGroup as default
};

==> vue-button-group-2.21.0.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $prefix, $setup, $props } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import "@opentinyvue/vue-theme/button-group/index.css";
var template = function template2(mode) {
  var _process$env;
  typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  return PcTemplate;
};
var buttonGroupProps = _extends({}, $props, {
  size: String,
  data: {
    type: Array,
    default: function _default() {
      return [];
    }
  },
  plain: Boolean,
  modelValue: [String, Number],
  disabled: Boolean,
  valueField: {
    type: String,
    default: "value"
  },
  textField: {
    type: String,
    default: "text"
  },
  showMore: Number,
  showEdit: {
    type: Boolean,
    default: false
  },
  border: {
    type: Boolean,
    default: true
  }
});
var ButtonGroup = defineComponent({
  name: $prefix + "ButtonGroup",
  provide: function provide() {
    return {
      buttonGroup: this
    };
  },
  props: buttonGroupProps,
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "2.21.0";
ButtonGroup.model = {
  prop: "modelValue",
  event: "update:modelValue"
};
ButtonGroup.install = function(Vue) {
  Vue.component(ButtonGroup.name, ButtonGroup);
};
ButtonGroup.version = version;
export {
  ButtonGroup as default
};
